#!/usr/bin/env python

import os
from string import find, strip

from MolKit import Read
from MolKit.pdbWriter import PdbqtWriter
from AutoDockTools.atomTypeTools import AutoDock4_AtomTyper
from AutoDockTools.DockingParameters import DockingParameters
from AutoDockTools.DockingParameters import genetic_algorithm_list4
from AutoDockTools.DockingParameters import genetic_algorithm_local_search_list4
from AutoDockTools.DockingParameters import local_search_list4
from AutoDockTools.DockingParameters import simulated_annealing_list4




if __name__ == '__main__':
    import sys
    import getopt

    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: dpf3_to_dpf4.py -s dpf3_stem -r receptor_filename -l ligand_filename"
        print
        print "    Description of command..."
        print "        [-s]    dpf3_stem"
        print "        [-r]    receptor_filename (pdbqt)"
        print "        [-l]    ligand_filename (pdbqt)"
        print "    Optional parameters:"
        print "        [-o]    outputfilename"
        print "        [-p]    parameter_list "
        print "                (default is 'genetic_algorithm_local_search_list4')"
        print "        [-v]    verbose output"


    # process command arguments
    try:
        #opt_list, args = getopt.getopt(sys.argv[1:], 'r:o:bs:ampvHG')
        opt_list, args = getopt.getopt(sys.argv[1:], 's:r:l:o:p:v')

    except getopt.GetoptError, msg:
        print 'dpf3_to_dpf4.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-s: pdbq_stem
    dpf3_filename =  None

    #-r: receptor_filename
    receptor_filename =  None

    #-l: ligand_filename
    ligand_filename =  None

    # optional parameters

    #-p: parameter_list
    parameter_list =  'genetic_algorithm_local_search_list4'
    verbose = None
    outputfilename = None

    #'s:r:l:o:p:v'
    for o, a in opt_list:
        if o in ('-s', '--s'):
            dpf3_stem = a
            dpf3_filename = a + '.dpf'
            if verbose: print 'set dpf3_filename to ', dpf3_filename
        if o in ('-r', '--r'):
            receptor_filename = a
            if verbose: print 'set receptor_filename to ', receptor_filename
            extension = os.path.splitext(receptor_filename)[1]
            if extension!='.pdbqt':
                print receptor_filename, " not in pdbqt format"
                usage()
                sys.exit()
        if o in ('-l', '--l'):
            ligand_filename = a
            if verbose: print 'set ligand_filename to ', ligand_filename
            #check that the ligand_filename type is pdbqt
            extension = os.path.splitext(ligand_filename)[1]
            if extension!='.pdbqt':
                print ligand_filename, " not in pdbqt format"
                usage()
                sys.exit()
        if o in ('-p', '--p'):
            parameter_list = a
            if verbose: print 'set parameter_list to ', parameter_list
        if o in ('-o', '--o'):
            outputfilename = a
            if verbose: print 'set outputfilename to ', outputfilename
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()


    if not ligand_filename:
        print 'dpf3_to_dpf4: ligand_filename must be specified.'
        usage()
        sys.exit()
    if not receptor_filename:
        receptor_filename = dpf3_stem + '.pdbqt'
        print "dpf3_to_dpf4: using default receptor_filename:", receptor_filename
    if not dpf3_filename:
        print 'dpf3_to_dpf4: no dpf3_filename specified using GridParameter defaults'

    parms= {}
    parms['simulated_annealing_list4'] =  simulated_annealing_list4
    parms['genetic_algorithm_list4'] = genetic_algorithm_list4
    parms['genetic_algorithm_local_search_list4'] = genetic_algorithm_local_search_list4
    parms['local_search_list4'] = local_search_list4 

    #what about nucleic acids???
    DPO4 = DockingParameters()
    print "default: ligand_types=", DPO4['ligand_types']['value']
    orig_compute_unbound_extended_flag = DPO4['compute_unbound_extended_flag']['value']
    if dpf3_filename:
        DPO4.read(dpf3_filename)
        if verbose: print 'read ', dpf3_filename
        DPO4['compute_unbound_extended_flag']['value'] = orig_compute_unbound_extended_flag
    else:
        if verbose: print 'using dpo defaults'
    DPO4.set_ligand(ligand_filename)
    DPO4.set_version("4.1")
    DPO4['set_sw1']['value'] = 0
    DPO4['set_sw1_flag']['value'] = 0
    DPO4['set_psw1']['value'] = 1
    DPO4['set_psw1_flag']['value'] = 1
    res = DPO4.set_ligand_types_from_filename(ligand_filename)
    if res=="ERROR": raise 'unreadable file', ligand_filename
    if verbose: 
        print "ligand_types=", DPO4['ligand_types']['value']
        print 'set ligand to  ', ligand_filename
    DPO4.set_receptor(receptor_filename)
    if verbose: print 'set receptor to  ', receptor_filename
    if outputfilename is None:
        outputfilename = dpf3_stem + '_4.dpf'

    DPO4.write4(outputfilename, parms[parameter_list])
    if verbose: 
        print "wrote ", outputfilename, ' using:'
        for p in parameter_list:
            print p
    

# To execute this command type:
# dpf3_to_dpf4.py -s dpf3_stem -r receptor_filename -l ligand_filename -v




#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/process_VinaResult.py,v 1.5 2010/11/09 00:09:24 rhuey Exp $
#
# $Id: process_VinaResult.py,v 1.5 2010/11/09 00:09:24 rhuey Exp $
#
import os, glob, time

from MolKit import Read
from AutoDockTools.Docking import Docking, VinaResultProcessor
from mglutil.math.rmsd import RMSDCalculator
from AutoDockTools.InteractionDetector import InteractionDetector




if __name__ == '__main__':
    import sys
    import getopt

    #'d:o:t:f:r:BLl:x:Dnc vh'

    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: process_VinaResult.py -f ADVina_resultfile -r receptor_filename"
        print
        print "    Description of command..."
        print "         -f     vina_resultfile"
        print "         -r     receptor filename "
        print "    Optional parameters:"
        print "        [-o]    outputfilestem (default is None yields resultfilenames 'ind_model1.pdbqt')"
        print "        [-m]    remove_model_str (remove 'model' from resultfilenames,eg 'ind_1.pdbqt', 'ind_2.pdbqt'...)"
        print "        [-B]    process best result only 'ind_model1.pdbqt' (default is to output a file for each MODEL) "
        print "        [-x]    maximum number of models to process (default is to process all models)"
        print "        [-c]    do not detect close contacts (default is to detect them)"
        print "        [-p]    report pi-pi interactions (default is NOT to detect pi-pi or pi-cation)"
        print "        [-v]    verbose output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'f:r:o:Bx:mcpvh')
    except getopt.GetoptError, msg:
        print 'process_VinaResult.py: %s' %msg
        usage()
        sys.exit(2)
    
    # initialize required parameters
    #-f: vina_resultfile
    vina_resultfile =  None
    #-r receptor_filename 
    receptor_filename = None

    # optional parameters
    #-o: outputfilestem
    outputfilestem =  None
    #-m: remove_model_str
    remove_model_str =  False
    #-B create outputfile for best model only
    best_only = False
    #-c do NOT detect_close_contacts
    detect_close_contacts = True
    #-p include detection of pi-pi and pi-cation interactions 
    detect_pi = False
    #-x maximum number of models to process
    max_models = -1  #use ?None? instead  

    # -v verbose output
    verbose = None


    #'f:r:o:Bcpx vh'
    for o, a in opt_list:
        #required parameters
        if o in ('-f', '--f'):
            vina_resultfile = a
            if verbose: print 'set vina_resultfile to ', a
        if o in ('-r', '--r'):
            receptor_filename = a
            if verbose: print 'set receptor_filename to ', receptor_filename
        #optional parameters
        if o in ('-o', '--o'):
            outputfilestem = a
            if verbose: print 'set outputfilestem to ', outputfilestem
        if o in ('-m', '--m'):
            remove_model_str = True
            if verbose: print 'set remove_model_str to ', remove_model_str
        if o in ('-B', '--B'):
            best_only = True
            if verbose: print 'best_only is ', best_only
        if o in ('-x', '--x'):
            max_models = int(a) 
            if verbose: print 'At most '+ max_models + ' will be created'
        if o in ('-c', '--c'):
            detect_close_contacts = False
            if verbose: print 'set detect_close_contacts to ', detect_close_contacts
        if o in ('-p', '--p'):
            detect_pi = True
            if verbose: print 'set detect_pi interactions to ', detect_pi
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()

    if not  vina_resultfile:
        print 'process_VinaResult: vina_resultfile must be specified.'
        usage()
        sys.exit()

    if not  receptor_filename:
        print 'process_VinaResult: receptor_filename must be specified.'
        usage()
        sys.exit()


    #read the vina result
    ligMols = Read(vina_resultfile)
    if not len(ligMols):
        print "unable to read vina resultfile ", vina_resultfile
        sys.exit()

    #check that receptor_filename exists
    try:
        assert os.path.exists(receptor_filename)
    except:
        print "Sorry unable to find receptor ", receptor_filename
        sys.exit()


    vrp = VinaResultProcessor( receptor_filename=receptor_filename,
                                 detect_pi=detect_pi, 
                                 detect_close_contacts=detect_close_contacts) 
    vrp.process( vina_resultfile, outputfilestem=outputfilestem, 
                                 remove_model_str=remove_model_str, 
                                 best_only=best_only) 


# process_VinaResult.py 
#       -f vina_resultfile 
#       -r receptor_filename
#optional:
#-o    outputfilestem (default is None resulting in filenames 'ind_model1.pdbqt','ind_model2.pdbqt' ...)"
#-m    remove_model_str (default is False resulting in filenames 'ind_model1.pdbqt','ind_model2.pdbqt' ...)"
#                       (if True results in filenames 'ind_1.pdbqt','ind_2.pdbqt' ...)"
#-B    process best result only (default is create a pdbqt+ file for each MODEL)"
#-x    maximum number of MODELS to process (default is to process all)"
#-c    do not detect atoms in close contact (default is TO detect them)"
#-p    report pi-pi interactions (default is NOT to detect pi-pi or pi-cation)"
#-v    verbose output
#-h    print usage statement




########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Tuesday 27 July 2010 18:39:11 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/Adt/Macro/GromosCluster.py,v 1.3 2010/07/28 01:48:07 jren Exp $
#
# $Id: GromosCluster.py,v 1.3 2010/07/28 01:48:07 jren Exp $
#

from NetworkEditor.macros import MacroNode
from NetworkEditor.macros import MacroNode
class GromosCluster(MacroNode):
    '''
    This node runs the GROMOS Cluster web service.

    Inputs: 
        port 1: trajectory pdb file
        port 2: active residue pdb file
        port 3: rmsd cutoff
        port 4: directory to download pdb results to
    Output:
        directory path that contains the result pdb files
    '''

    def __init__(self, constrkw={}, name='GromosCluster', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        from Vision.StandardNodes import stdlib
        from WebServices.VisionInterface.WSNodes import wslib
        net.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass

    def afterAddingToNetwork(self):
        masterNet = self.macroNetwork
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        from Vision.StandardNodes import stdlib
        from WebServices.VisionInterface.WSNodes import wslib
        ## building macro network ##
        GromosCluster_33 = self
        from traceback import print_exc
        from Vision.StandardNodes import stdlib
        from WebServices.VisionInterface.WSNodes import wslib
        masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass
        try:
            ## saving node input Ports ##
            input_Ports_34 = self.macroNetwork.ipNode
            apply(input_Ports_34.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_34=None

        try:
            ## saving node output Ports ##
            output_Ports_35 = self.macroNetwork.opNode
            apply(output_Ports_35.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
            output_Ports_35.move(236, 302)
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_35=None

        try:
            ## saving node GROMOS_ClusterFiles_kryptonite_nbcr_net ##
            from NetworkEditor.items import FunctionNode
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36 = FunctionNode(functionOrString='GROMOS_ClusterFiles_kryptonite_nbcr_net', host="http://kryptonite.nbcr.net/opal2", namedArgs={'expert_options': '', 'rmsd': '0.125', 'traj': '', 'prefix': '', 'default_options': '-o -g -dist -ev -sz -tr -ntr -clid -cl', 'active': '', 'localRun': False, 'method': 'gromos', 'execPath': ''}, constrkw={'functionOrString': "'GROMOS_ClusterFiles_kryptonite_nbcr_net'", 'host': '"http://kryptonite.nbcr.net/opal2"', 'namedArgs': {'expert_options': '', 'rmsd': '0.125', 'traj': '', 'prefix': '', 'default_options': '-o -g -dist -ev -sz -tr -ntr -clid -cl', 'active': '', 'localRun': False, 'method': 'gromos', 'execPath': ''}}, name='GROMOS_ClusterFiles_kryptonite_nbcr_net', library=wslib)
            self.macroNetwork.addNode(GROMOS_ClusterFiles_kryptonite_nbcr_net_36,200,98)
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['expert_options'].configure, (), {'defaultValue': None})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['rmsd'].configure, (), {'defaultValue': None, 'required': True})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['traj'].configure, (), {'defaultValue': None, 'required': True})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['prefix'].configure, (), {'defaultValue': None})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['default_options'].configure, (), {'defaultValue': None})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['active'].configure, (), {'defaultValue': None, 'required': True})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['method'].configure, (), {'defaultValue': None})
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['expert_options'].widget.set(r"", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['rmsd'].rebindWidget()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['rmsd'].widget.set(r"0.125", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['rmsd'].unbindWidget()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['traj'].rebindWidget()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['traj'].widget.set(r"", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['traj'].unbindWidget()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['prefix'].widget.set(r"", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['default_options'].widget.set(r"-o -g -dist -ev -sz -tr -ntr -clid -cl", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['active'].rebindWidget()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['active'].widget.set(r"", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['active'].unbindWidget()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['localRun'].widget.set(0, run=False)
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['method'].widget.configure, (), {'choices': ('gromos', 'linkage', 'jarvis-patrick', 'monte-carlo', 'diagonalization')})
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['method'].widget.set(r"gromos", run=False)
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36.inputPortByName['execPath'].widget.set(r"", run=False)
            apply(GROMOS_ClusterFiles_kryptonite_nbcr_net_36.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named GROMOS_ClusterFiles_kryptonite_nbcr_net in network self.macroNetwork"
            print_exc()
            GROMOS_ClusterFiles_kryptonite_nbcr_net_36=None

        try:
            ## saving node GetClusterFrameLink ##
            from WebServices.VisionInterface.WSNodes import GetMainURLFromListNode
            GetClusterFrameLink_46 = GetMainURLFromListNode(constrkw={}, name='GetClusterFrameLink', library=wslib)
            self.macroNetwork.addNode(GetClusterFrameLink_46,200,164)
            apply(GetClusterFrameLink_46.inputPortByName['urls'].configure, (), {'defaultValue': None})
            code = """def doit(self, urls):   
            url = urls[0]
            filename = url.split('''/''')[len(url.split('''/'''))-1]
            nurl = url.strip(filename)
            nurl = nurl + '''cluster_frames'''
            pass
            self.outputData(newurl=nurl)

"""
            GetClusterFrameLink_46.configure(function=code)
            apply(GetClusterFrameLink_46.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore GetMainURLFromListNode named GetClusterFrameLink in network self.macroNetwork"
            print_exc()
            GetClusterFrameLink_46=None

        try:
            ## saving node DownloadSaveDir ##
            from WebServices.VisionInterface.WSNodes import DownloadSaveDirNode
            DownloadSaveDir_51 = DownloadSaveDirNode(constrkw={}, name='DownloadSaveDir', library=wslib)
            self.macroNetwork.addNode(DownloadSaveDir_51,253,241)
            apply(DownloadSaveDir_51.inputPortByName['url'].configure, (), {'defaultValue': None})
            apply(DownloadSaveDir_51.inputPortByName['path'].configure, (), {'defaultValue': None})
            apply(DownloadSaveDir_51.inputPortByName['cutdirs'].configure, (), {'defaultValue': None})
            DownloadSaveDir_51.inputPortByName['url'].rebindWidget()
            DownloadSaveDir_51.inputPortByName['url'].widget.set(r"", run=False)
            DownloadSaveDir_51.inputPortByName['url'].unbindWidget()
            apply(DownloadSaveDir_51.configure, (), {'paramPanelImmediate': 1})
        except:
            print "WARNING: failed to restore DownloadSaveDirNode named DownloadSaveDir in network self.macroNetwork"
            print_exc()
            DownloadSaveDir_51=None

        try:
            ## saving node Entry ##
            from Vision.StandardNodes import EntryNE
            Entry_54 = EntryNE(constrkw={}, name='Entry', library=stdlib)
            self.macroNetwork.addNode(Entry_54,347,154)
            apply(Entry_54.inputPortByName['entry'].configure, (), {'defaultValue': None})
            Entry_54.inputPortByName['entry'].widget.set(r"3", run=False)
            apply(Entry_54.configure, (), {'paramPanelImmediate': 1})
        except:
            print "WARNING: failed to restore EntryNE named Entry in network self.macroNetwork"
            print_exc()
            Entry_54=None

        #self.macroNetwork.run()
        self.macroNetwork.freeze()

        ## saving connections for network GromosCluster ##
        input_Ports_34 = self.macroNetwork.ipNode
        if input_Ports_34 is not None and GROMOS_ClusterFiles_kryptonite_nbcr_net_36 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_34, GROMOS_ClusterFiles_kryptonite_nbcr_net_36, "new", "traj", blocking=True
                    , splitratio=[0.45411042113261574, 0.54335719372693991])
            except:
                print "WARNING: failed to restore connection between input_Ports_34 and GROMOS_ClusterFiles_kryptonite_nbcr_net_36 in network self.macroNetwork"
        if input_Ports_34 is not None and GROMOS_ClusterFiles_kryptonite_nbcr_net_36 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_34, GROMOS_ClusterFiles_kryptonite_nbcr_net_36, "new", "active", blocking=True
                    , splitratio=[0.50935546751136695, 0.51596797621119816])
            except:
                print "WARNING: failed to restore connection between input_Ports_34 and GROMOS_ClusterFiles_kryptonite_nbcr_net_36 in network self.macroNetwork"
        if input_Ports_34 is not None and GROMOS_ClusterFiles_kryptonite_nbcr_net_36 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_34, GROMOS_ClusterFiles_kryptonite_nbcr_net_36, "new", "rmsd", blocking=True
                    , splitratio=[0.72697457023572398, 0.5609730307022871])
            except:
                print "WARNING: failed to restore connection between input_Ports_34 and GROMOS_ClusterFiles_kryptonite_nbcr_net_36 in network self.macroNetwork"
        if GROMOS_ClusterFiles_kryptonite_nbcr_net_36 is not None and GetClusterFrameLink_46 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GROMOS_ClusterFiles_kryptonite_nbcr_net_36, GetClusterFrameLink_46, "result", "urls", blocking=True
                    , splitratio=[0.72920790745169972, 0.25586352865051565])
            except:
                print "WARNING: failed to restore connection between GROMOS_ClusterFiles_kryptonite_nbcr_net_36 and GetClusterFrameLink_46 in network self.macroNetwork"
        if GetClusterFrameLink_46 is not None and DownloadSaveDir_51 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetClusterFrameLink_46, DownloadSaveDir_51, "newurl", "url", blocking=True
                    , splitratio=[0.6813604229397745, 0.24060738045908744])
            except:
                print "WARNING: failed to restore connection between GetClusterFrameLink_46 and DownloadSaveDir_51 in network self.macroNetwork"
        if input_Ports_34 is not None and DownloadSaveDir_51 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_34, DownloadSaveDir_51, "new", "path", blocking=True
                    , splitratio=[0.26234570709625593, 0.71051250549253275])
            except:
                print "WARNING: failed to restore connection between input_Ports_34 and DownloadSaveDir_51 in network self.macroNetwork"
        output_Ports_35 = self.macroNetwork.opNode
        if DownloadSaveDir_51 is not None and output_Ports_35 is not None:
            try:
                self.macroNetwork.connectNodes(
                    DownloadSaveDir_51, output_Ports_35, "output", "new", blocking=True
                    , splitratio=[0.32827353595918307, 0.22147048732628238])
            except:
                print "WARNING: failed to restore connection between DownloadSaveDir_51 and output_Ports_35 in network self.macroNetwork"
        if Entry_54 is not None and DownloadSaveDir_51 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Entry_54, DownloadSaveDir_51, "string", "cutdirs", blocking=True
                    , splitratio=[0.28715327854931738, 0.50903858482741082])
            except:
                print "WARNING: failed to restore connection between Entry_54 and DownloadSaveDir_51 in network self.macroNetwork"
        self.macroNetwork.runOnNewData.value = False

        ## modifying MacroInputNode dynamic ports
        input_Ports_34 = self.macroNetwork.ipNode
        input_Ports_34.outputPorts[1].configure(name='GROMOS_ClusterFiles_kryptonite_nbcr_net_traj')
        input_Ports_34.outputPorts[2].configure(name='GROMOS_ClusterFiles_kryptonite_nbcr_net_active')
        input_Ports_34.outputPorts[3].configure(name='GROMOS_ClusterFiles_kryptonite_nbcr_net_rmsd')
        input_Ports_34.outputPorts[4].configure(name='DownloadSaveDir_path')

        ## modifying MacroOutputNode dynamic ports
        output_Ports_35 = self.macroNetwork.opNode
        output_Ports_35.inputPorts[1].configure(singleConnection='auto')
        output_Ports_35.inputPorts[1].configure(name='DownloadSaveDir_output')
        ## configure MacroNode input ports
        GromosCluster_33.inputPorts[0].configure(name='GROMOS_ClusterFiles_kryptonite_nbcr_net_traj')
        GromosCluster_33.inputPorts[0].configure(datatype='string')
        GromosCluster_33.inputPorts[1].configure(name='GROMOS_ClusterFiles_kryptonite_nbcr_net_active')
        GromosCluster_33.inputPorts[1].configure(datatype='string')
        GromosCluster_33.inputPorts[2].configure(name='GROMOS_ClusterFiles_kryptonite_nbcr_net_rmsd')
        GromosCluster_33.inputPorts[2].configure(datatype='string')
        GromosCluster_33.inputPorts[3].configure(name='DownloadSaveDir_path')
        GromosCluster_33.inputPorts[3].configure(datatype='string')
        ## configure MacroNode output ports
        GromosCluster_33.outputPorts[0].configure(name='DownloadSaveDir_output')
        GromosCluster_33.outputPorts[0].configure(datatype='string')

        GromosCluster_33.shrink()

        ## reset modifications ##
        GromosCluster_33.resetTags()
        GromosCluster_33.buildOriginalList()



#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/write_rigid_ligand.py,v 1.1 2008/05/28 16:48:41 rhuey Exp $
#
import os, string
from MolKit import Read




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        print "Usage: write_rigid_ligand.py "
        print "     This writes a rigid ligandfile with no rotatable bonds"
        print "        -l ligand_filename"
        print "    Optional parameters:"
        print "        [-o pdbqt_filename] (default ligandstem_rigid.pdbqt)"
        print "        [-v]    verbose output"

    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'l:o:vh')
    except getopt.GetoptError, msg:
        print 'write_rigid_ligand.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    # optional parameters
    verbose = None
    #-l ligandfilename
    ligandfilename = None
    #-o outputfilename
    outputfilename = None

    #'l:o:vh'
    for o, a in opt_list:
        if o in ('-l', '--l'):
            ligandfilename = a
            if verbose: print 'set ligandfilename to ', a
        if o in ('-o', '--o'):
            outputfilename = a
            if verbose: print 'set outputfilename to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()
    if not ligandfilename:
        print "write_rigid_ligand.py: ligandfilename must be specified."
        usage()
        sys.exit()

    lig = Read(ligandfilename)[0]
    ext = os.path.splitext(ligandfilename)[1]
    if outputfilename is None:
        outputfilename = lig.name + "_rigid" + ext
    if verbose: print 'set outputfilename to ', outputfilename
    parser = lig.parser
    optr = open(outputfilename, 'w')
    #have to add newline character to lines read from dlg
    for l in parser.allLines:
        if l.find("active torsions:")>-1:
            nl = "REMARK 0 active torsions:\n"
            optr.write(nl)
        elif l.find("A    between atoms:")>-1:
            ll = l.split()
            #REMARK,1,A,between,atoms:,N1_1517,and,C31_1555"
            nl = ll[0] + "       I    " + string.join(ll[3:]) + "\n"
            optr.write(nl)
        elif l.find("TORSDOF")==0:
            nl = "ENDROOT\n"
            optr.write(nl)
            optr.write(l)
        elif l.find("BRANCH")==-1 and l.find("ENDBRANCH")==-1 and l.find("ENDROOT")==-1:
            optr.write(l)
    if verbose:
        print 'wrote %s' %outputfilename


# To execute this command type:
# write_rigid_ligand.py  -l ligandfilename [-o outputfilename] -v







#
#
#
#
# $Id: test_prepare_dpf4.py,v 1.12 2012/05/21 18:44:35 rhuey Exp $
#

import unittest, os, sys
from time import sleep
from string import split, find
from MolKit import Read
from AutoDockTools.DockingParameters import DockingParameters

class BaseTests(unittest.TestCase):

    def test_default(self):
        """
    prepare_dpf4.py -l pdbqt_file -r pdbqt_file -"
       [-l ligand_filename]"
       [-r receptor_filename]"
    Optional parameters:"
       [-i reference_dpf_filename]"
       [-o output_dpf_filename]"
       [-p parameter=newvalue]"
       [-v verbose output]"

        """
        filename = "test_default.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -o " + filename 
        #cmd = "../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -o " + filename 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_use_reference_dpf(self):
        """
        test setting parameters using reference dpf
        options
           -i dpffilename
        """
        filename = "test_ref4.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -i ref_1ebg.dpf -o " + filename
        #cmd = "../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -i ref_1ebg.dpf -o " + filename
        os.system(cmd)
        #sleep(5)
        ref_dpo = DockingParameters()
        ref_dpo.read('ref_1ebg.dpf')
        dpo = DockingParameters()
        dpo.read(filename)
        for key, refval in ref_dpo.items():
            if dpo[key]['value']!=refval['value']:
                print "failing.. ", key
            self.assertEqual(dpo[key]['value'], refval['value'])
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_set_version_4(self):
        """
        test setting autodock_parameter_version to 4.0
        options
           -p autodock_parameter_version
        """
        filename = "test_autodock_parameter_version.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p autodock_parameter_version=4.1 -o " + filename
        #cmd = "../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -i ref_1ebg.dpf -o " + filename
        os.system(cmd)
        #sleep(5)
        ref_dpo = DockingParameters()
        ref_dpo.read('ref_autodock_parameter_version4.dpf')
        dpo = DockingParameters()
        dpo.read(filename)
        for key,refval in ref_dpo.items():
            #print "checking ", key
            if dpo[key]['value']!=refval['value']:
                print "failing.. ", key
            self.assertEqual(dpo[key]['value'], refval['value'])
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_set_version_4_with_unbound_model(self):
        """
        test setting unbound_model to 'extended'
        options
           -p autodock_parameter_version
        """
        filename = "test_autodock_parameter_version.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p autodock_parameter_version=4.1 -o " + filename
        #cmd = "../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -i ref_1ebg.dpf -o " + filename
        os.system(cmd)
        #sleep(5)
        ref_dpo = DockingParameters()
        ref_dpo.read('ref_autodock_parameter_version4.dpf')
        dpo = DockingParameters()
        dpo.read(filename)
        for key,refval in ref_dpo.items():
            #print "checking ", key
            if dpo[key]['value']!=refval['value']:
                print "failing.. ", key
            self.assertEqual(dpo[key]['value'], refval['value'])
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_setting_parameter(self):
        """
        test setting parameter directly
        options
           -p parameter=newvalue
        """
        filename = "test_param.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p ga_num_evals=100000000  -o " + filename
        #cmd = "../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p ga_num_evals=100000000  -o " + filename
        os.system(cmd)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo['ga_num_evals']['value'], 100000000) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_setting_2_parameters(self):
        """
        test setting 2 parameters directly
        options
           -p parameter=newvalue
           -p parameter2=newvalue2
        """
        filename = "test_2params4.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p ga_pop_size=200 -p ga_num_evals=1234567 -o " + filename
        os.system(cmd)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo['ga_pop_size']['value'], 200) 
        self.assertEqual(int(dpo['ga_num_evals']['value']), 1234567) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_setting_3_parameters(self):
        """
        test setting 3 parameters directly
        options
           -p parameter=newvalue
           -p parameter2=newvalue2
           -p parameter3=newvalue3
        """
        filename = "test_3params.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -p ga_pop_size=200 -p set_sw1=0 -p set_psw1=1  -o " + filename
        os.system(cmd)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo['ga_pop_size']['value'], 200) 
        self.assertEqual(int(dpo['set_psw1']['value']), 1) 
        self.assertEqual(dpo['set_sw1']['value'],0)
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)

# test each parameter separately
    def test_outlev(self):
        """
        test setting outlev
        """
        filename = "test_outlev.dpf"
        param = 'outlev'
        val = 6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_seed(self):
        """
        test setting seed
        """
        filename = "test_seed.dpf"
        param = 'seed'
        val = [1234,56789]
        testval = "[1234,56789]"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_types(self):
        """
        test setting types
        """
        filename = "test_types.dpf"
        param = 'types'
        val = testval = "ACHN"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_fld(self):
        """
        test setting fld
        NB: This is normally set by specifying the receptor filename 
        """
        filename = "test_fld.dpf"
        param = 'fld'
        val = testval = "hsg1.maps.fld"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_map(self):
        """
        test setting map
        NB: This is normally set by specifying the receptor filename 
        """
        filename = "test_map.dpf"
        param = 'map'
        val = testval = "ref_hsg1.OA.map"  #the last atom map
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_move(self):
        """
        test setting move
        NB: This is normally set by specifying the ligand filename 
        """
        filename = "test_move.dpf"
        param = 'move'
        val = testval = "ind.pdbqt"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_about_root_atoms_only(self):
        """
        test setting root using about_root_atoms_only 
        options
           -A    #sets 'about_root_atoms_only' to True
        """
        filename = "test_about_root_atoms_only.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = 'set PYTHONPATH=%s'%sys.path[0]
        cmd = cmd + "; ../prepare_dpf42.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -A   -o " + filename
        #cmd = "../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p ga_num_evals=100000000  -o " + filename
        os.system(cmd)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo['about']['value'][0], 17.367) 
        self.assertEqual(dpo['about']['value'][1], 5.269) 
        self.assertEqual(dpo['about']['value'][2], 18.983) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_tran0(self):
        """
        test setting tran0
        """
        filename = "test_about.dpf"
        param = 'tran0'
        val = [1.0,2.0,3.0]
        #testval = str(val)
        testval = "[1.0,2.0,3.0]"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_quat0(self):
        """
        test setting quat0
        """
        filename = "test_about.dpf"
        param = 'quat0'
        val = [1.0,2.0,3.0,4.0]
        #testval = str(val)
        testval = "[1.0,2.0,3.0,4.0]"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ndihe(self):
        """
        test setting ndihe
        NB: This is normally set by specifying the ligand filename 
        """
        filename = "test_ndihe.dpf"
        param = 'ndihe'
        val = 12
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_dihe0(self):
        """
        test setting dihe0
        """
        filename = "test_about.dpf"
        param = 'dihe0'
        val = [1.0,2.0,3.0,4.0]
        #testval = str(val)
        testval = "[1.0,2.0,3.0,4.0]"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_max_its(self):
        """
        test setting sw_max_its
        """
        filename = "test_sw_max_its.dpf"
        param = 'sw_max_its'
        val = 123
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_max_succ(self):
        """
        test setting sw_max_succ
        """
        filename = "test_sw_max_succ.dpf"
        param = 'sw_max_succ'
        val = 321 
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_max_fail(self):
        """
        test setting sw_max_fail
        """
        filename = "test_sw_max_fail.dpf"
        param = 'sw_max_fail'
        val = 222 
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_elecmap(self):
        """
        test not being able to set elecmap
        NB: This is ALWAYS set by specifying the receptor filename 
        and value remains ''
        """
        filename = "test_elecmap.dpf"
        param = 'elecmap'
        val = testval = "hsg1.e.map"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        #???IS THIS AN EXCEPTION???
        self.assertEqual(dpo[param]['value'], 'hsg1.e.map') 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_torsdof(self):
        """
        test setting torsdof
        NB: This is normally set by specifying the ligand filename 
        """
        filename = "test_torsdof.dpf"
        param = 'torsdof'
        val = [12,0.3113]
        #testval = str(val)
        testval = "[12,0.3113]"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_intelec(self):
        """
        test setting intelec
        """
        filename = "test_intelec.dpf"
        param = 'intelec'
        val = 1
        #testval = str(val)
        testval = '1'
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_rmstol(self):
        """
        test setting rmstol
        """
        filename = "test_rmstol.dpf"
        param = 'rmstol'
        val = 0.10
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_extnrg(self):
        """
        test setting extnrg
        """
        filename = "test_extnrg.dpf"
        param = 'extnrg'
        val = 1000000
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_e0max(self):
        """
        test setting e0max
        NB: This is normally set by specifying the ligand filename 
        """
        filename = "test_e0max.dpf"
        param = 'e0max'
        val = [1.,31133]
        #testval = str(val)
        testval = "[1.,31133]"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_pop_size(self):
        """
        test setting ga_pop_size
        """
        filename = "test_ga_pop_size.dpf"
        param = 'ga_pop_size'
        val = 10
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_num_evals(self):
        """
        test setting ga_num_evals
        """
        filename = "test_ga_num_evals.dpf"
        param = 'ga_num_evals'
        val = 1000
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_num_generations(self):
        """
        test setting ga_num_generations
        """
        filename = "test_ga_num_generations.dpf"
        param = 'ga_num_generations'
        val = 10
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_elitism(self):
        """
        test setting ga_elitism
        """
        filename = "test_ga_elitism.dpf"
        param = 'ga_elitism'
        val = 0.0006
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_mutation_rate(self):
        """
        test setting ga_mutation_rate
        """
        filename = "test_ga_mutation_rate.dpf"
        param = 'ga_mutation_rate'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_crossover_rate(self):
        """
        test setting ga_crossover_rate
        """
        filename = "test_ga_crossover_rate.dpf"
        param = 'ga_crossover_rate'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_window_size(self):
        """
        test setting ga_window_size
        """
        filename = "test_ga_window_size.dpf"
        param = 'ga_window_size'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_cauchy_alpha(self):
        """
        test setting ga_cauchy_alpha
        """
        filename = "test_ga_cauchy_alpha.dpf"
        param = 'ga_cauchy_alpha'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ga_cauchy_beta(self):
        """
        test setting ga_cauchy_beta
        """
        filename = "test_ga_cauchy_beta.dpf"
        param = 'ga_cauchy_beta'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_set_ga(self):
        """
        test setting set_ga
        """
        filename = "test_set_ga.dpf"
        param = 'set_ga'
        val = 1
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_max_its(self):
        """
        test setting sw_max_its
        """
        filename = "test_sw_max_its.dpf"
        param = 'sw_max_its'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_max_succ(self):
        """
        test setting sw_max_succ
        """
        filename = "test_sw_max_succ.dpf"
        param = 'sw_max_succ'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_rho(self):
        """
        test setting sw_rho
        """
        filename = "test_sw_rho.dpf"
        param = 'sw_rho'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_sw_lb_rho(self):
        """
        test setting sw_lb_rho
        """
        filename = "test_sw_lb_rho.dpf"
        param = 'sw_lb_rho'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_ls_search_freq(self):
        """
        test setting ls_search_freq
        """
        filename = "test_ls_search_freq.dpf"
        param = 'ls_search_freq'
        val = 0.6
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)


    def test_set_psw1(self):
        """
        test setting set_psw1
        """
        filename = "test_set_psw1.dpf"
        param = 'set_psw1'
        val = 1
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 
        #if os.path.exists(filename):
        #    cmd = "rm  " + filename
        #    os.system(cmd)



    def test_unbound_model_extended(self):
        """
        test setting unbound_model  to 'extended'
        """
        filename = "test_unbound_model_extended.dpf"
        param = 'unbound_model'
        val = 'extended'
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p unbound_model_flag=1 -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 


    def test_epdb_flag(self):
        """
        test setting epdb_flag
        """
        filename = "test_epdb_flag.dpf"
        param = 'epdb_flag'
        val = 1
        testval = str(val)
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        dpo = DockingParameters()
        dpo.read(filename)
        self.assertEqual(dpo[param]['value'], val) 


    #def test_include_1_4_interactions_flag(self):
    #    """
    #    test setting include_1_4_interactions_flag rh: 12/2011NO LONGER SUPPORTED
    #    """
    #    filename = "test_include_1_4_interactions_flag.dpf"
    #    param = 'include_1_4_interactions_flag'
    #    val = 1
    #    testval = str(val)
    #    if os.path.exists(filename):
    #        cmd = "rm  " + filename
    #        os.system(cmd)
    #    cmd = "set PYTHONPATH=%s"%sys.path[0]
    #    cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p %s=%s" %(filename, param, testval) 
    #    os.system(cmd)
    #    self.assertEqual(os.path.exists(filename), True)
    #    dpo = DockingParameters()
    #    dpo.read(filename)
    #    self.assertEqual(dpo[param]['value'], val) 

##    THIS ONE DOES NOT WORK!!!
##    def test_do_global_only(self):
##        """
##        test setting do_global_only
##        """
##        filename = "test_do_global_only.dpf"
##        param = 'do_global_only'
##        val = 12
##        testval = str(val)
##        if os.path.exists(filename):
##            cmd = "rm  " + filename
##            os.system(cmd)
##        cmd = "set PYTHONPATH=%s"%sys.path[0]
##        cmd = cmd + ";../prepare_dpf4.py -l ind.pdbqt -r ref_hsg1.pdbqt -o %s -p ga_run=%s -p %s=%s" %(filename, testval, param, testval) 
##        os.system(cmd)
##        self.assertEqual(os.path.exists(filename), True)
##        dpo = DockingParameters()
##        dpo.read(filename)
##        self.assertEqual(dpo['ga_run']['value'], val) 
##        #self.assertEqual(dpo[param]['value'], val) 
##        self.assertEqual(dpo['ga_run']['value'], val) 
##        if os.path.exists(filename):
##            cmd = "rm  " + filename
##            os.system(cmd)

    def test_LS_dpf_compare_lines(self):
        """
        test setting 'L' flag to use local search only parameters
        """
        filename = "test4_LS.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -L -o %s" %filename
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        testptr = open(filename)
        testlines = testptr.readlines()
        refptr = open("ref4_LS.dpf")
        reflines = refptr.readlines()
        refptr.close()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)
            


    def test_SA_dpf_compare_lines(self):
        """
        test setting 'S' flag to use simulated annealing parameters
        """
        filename = "test4_SA.dpf"
        if os.path.exists(filename):
            cmd = "rm  " + filename
            os.system(cmd)
        cmd = "set PYTHONPATH=%s"%sys.path[0]
        cmd = cmd + ";../prepare_dpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -S -o %s" %filename
        os.system(cmd)
        self.assertEqual(os.path.exists(filename), True)
        testptr = open(filename)
        testlines = testptr.readlines()
        refptr = open("ref4_SA.dpf")
        reflines = refptr.readlines()
        refptr.close()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)


if __name__ == '__main__':
    unittest.main()



#
# Last modified on Mon Nov 26 19:00:44 PST 2001 by lindy
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/autopilotCommands.py,v 1.3 2005/01/12 21:53:52 rhuey Exp $
#

"""
This Module facilitates the launching of large numbers of AutoDock jobs
"""


import string, Tkinter
from ViewerFramework.VFCommand import CommandGUI
from Pmv.mvCommand import MVCommand
from mglutil.gui.InputForm.Tk.gui import InputFormDescr

##  class ADParamSearch(MVCommand):
##      """facilitate parameter search"""

##      def onAddCmdToViewer(self):
##          self.dpo = DockingParameters.DockingParameters()
##          self.num_params = Tkinter.StringVar()
##      self.num_params.set('3')
##          self.base_dpf_name = Tkinter.StringVar()
##      self.parameters = []
##      self.first_values = []
##      self.last_value = []
##      self.step_value = []
##      for i in range(10):
##          self.first_values.append(Tkinter.StringVar())
##          self.last_values.append(Tkinter.StringVar())
##          self.step_values.append(Tkinter.StringVar())
##          self.parameter.append(Tkinter.StringVar())


##      def guiCallback(self):
##          #called each time the param_search button is pressed
##          print "called guiCallback in ADParamSearch"
##          if not hasattr(self, 'form'):
##              # create the ifd
##              self.buildGUI()
##          else:
##              # use the old ifd
##              self.form.deiconify()

##      def dismiss_cb(self):
##          self.form.withdraw()

##      def browse_cb(self):
##          base_dpf_name = self.vf.askFileOpen(types=[('base docking parameter file:', '*.dpf')], title = 'Select DPF')
##      if base_dpf_name:
##          # os.path.basename???
##          self.base_dpf_name.set(base_dpf_name)
##          #instantiate DPO
##          #read DPF
##          #set parameter lists accordingly


##      def doit_cb(self):
##          print "num_params:",  self.num_params.get()


##      def buildParamWids(self, num):
##      oldlen = len(self.paramWids)
##      diff = num - oldlen
##      if diff < 0:
##          for i in range(diff, 0, -1):
##          self.paramWids[i].grid_forget()
##      elif diff > 0:
##          self.paramWids[i].grid(self.grids[i])


##      def buildMenu(self, mB, nameList, varDict, oldvarDict, cmd):
##          for i in nameList:
##              if i not in varDict.keys():
##                  varDict[i]=Tkinter.IntVar()
##                  oldvarDict[i]=0
##          if hasattr(mB, 'menu'):
##              mB.menu.delete(1,'end')
##          else:
##              mB.menu = Tkinter.Menu(mB)
##              mB['menu']=mB.menu
##          #PACK all the entries
##          for i in varDict.keys():
##              mB.menu.add_radiobutton(label=i, var=varDict[i], command=cmd)

##      def buildParamMenu(self, paramButton, num, event=None):
##          #molMenubutton = self.ifd.entryByName['Mol List']['widget']
##          self.menuVars[num]={}
##          self.oldmenuVars[num]={}
##          paramNames = self.dpo.names
##      cmd = CallbackFunction(self.getParamVal, num)
##          self.buildMenu(paramButton,paramNames,self.menuVars[num],self.oldmolVar,cmd)

##      def buildEntry(self, i):
##          print 'in buildEntry'
    

##      def getEntries(self, num):
##      #first forget all the entries
##      for i in self.paramEntries:
##          i.grid_forget()
##      #then build new ones
##      for i in range(num):
##          print 'build ', i, 'th entry here'
##          self.buildEntry(i)

    
    

##      def buildGUI(self):
##          """Create the Parameter Search input form
##          """
##      self.ifd = ifd = InputFormDescr(title='Parameter Search')
##      # append new dicts to the ifd list
##      # one-widget-one-dict (generally)
##      ifd.append({ 'widgetType'   : Tkinter.Entry,
##               'label'        : "Number of Paramters",
##               'textvariable' : self.num_params,
##               'gridcfg' : { 'sticky' : Tkinter.W,
##                     'columnspan' : 2 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Entry,
##               'label'        : "Base DPF",
##               'textvariable' : self.base_dpf_name,
##               'gridcfg' : { 'sticky' : Tkinter.E,
##                     'columnspan' : 2,
##                     'row' : -1,
##                     'column' : 2 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Button,
##               'text'         : "Browse",
##               'command'      : self.browse_cb,
##               'gridcfg' : { 'sticky' : Tkinter.E,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 4 }
##               })
##      #
##      # Throw up some labels for the widgets to follow
##      #
##      ifd.append({ 'widgetType'   : Tkinter.Label,
##               'text'         : "Parameter",
##               'gridcfg' : { 'sticky' : Tkinter.W + Tkinter.E,
##                     'columnspan' : 1 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Label,
##               'text'         : "First Value",
##               'gridcfg' : { 'sticky' : Tkinter.W + Tkinter.E,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 1 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Label,
##               'text'         : "Last Value",
##               'gridcfg' : { 'sticky' : Tkinter.W + Tkinter.E,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 2 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Label,
##               'text'         : "Step Value",
##               'gridcfg' : { 'sticky' : Tkinter.W + Tkinter.E,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 3 }
##               })
##      #
##      # these widgets define the parameter and range
##      #
##      ifd.append({ 'widgetType'   : Pmw.ScrolledListBox,
##               'textvariable' : self.parameters,
##               'wcfg' : {'items' : self.dpo.docking_parameter_list,
##                     'listbox_height' : 1},
##               'gridcfg' : { 'sticky' : Tkinter.W,
##                     'columnspan' : 1 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Entry,
##               'textvariable' : self.first_value,
##               'gridcfg' : { 'sticky' : Tkinter.W,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 1 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Entry,
##               'textvariable' : self.last_value,
##               'gridcfg' : { 'sticky' : Tkinter.W,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 2 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Entry,
##               'textvariable' : self.step_value,
##               'gridcfg' : { 'sticky' : Tkinter.W,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 3 }
##               })

##      #
##      # 
##      #
##      ifd.append({ 'widgetType'   : Tkinter.Button,
##               'text'         : "Doit",
##               'command'      : self.doit_cb,
##               'gridcfg' : { 'sticky' : Tkinter.W + Tkinter.E,
##                     'columnspan' : 1 }
##               })
##      ifd.append({ 'widgetType'   : Tkinter.Button,
##               'text'         : "Dismiss",
##               'command'      : self.dismiss_cb,
##               'gridcfg' : { 'sticky' : Tkinter.W + Tkinter.E,
##                     'columnspan' : 1,
##                     'row' : -1,
##                     'column' : 1 }
##               })

##      # after the dict is built, do this
##          self.form = self.vf.getUserInput(self.ifd, modal= 0, blocking= 0)


##      def doit():
##          print 'in doit'

##  ADParamSearchGUI = CommandGUI()
##  ADParamSearchGUI.addMenuCommand('AutoToolsBar', 'AutoPilot', 'Parameter Search')

#
# Menu text
#
menuText = {}
menuText['AutoPilotMB'] = 'Pilot'
menuText['TemplateMB'] = 'Template'
menuText['DatabaseMB'] = 'Database'
menuText['ClusterMB'] = 'Cluster'

#
# Cluster command and GUICommand
#
class ADpilot_Cluster(MVCommand):
    """
    """

    #
    # the signiture for __call__ must be compatible with that of doit!!!
    #
    def __call__(self, **kw):
        """This method is invoked by saying self.vf.ADpilot_Cluster
        in the Python Shell.
        """
        apply(self.doitWrapper, (), kw)


    def onAddCmdToViewer(self):
        """Initialization.

        This method is called by vf.addCommand (below)
        """
        pass


    def doit(self):
        """The real work gets done here
        """
        print 'in doit'


class ADpilot_ClusterGUICommand(MVCommand):
    """A template GUI command"""

    #
    # signiture for __call__ must be compatible with that of doit!!!
    #
    def __call__(self, **kw):
        """This method is invoked by saying self.vf.ADpilot_ClusterGUICommand
        in the Python Shell.
        """
        apply(self.doitWrapper, (), kw)


    def onAddCmdToViewer(self):
        """Initialization.

        This method is called by vf.addCommand (below)
        """
        pass


    def buildFormDescr(self, formName):
        if formName == 'template':
            idf = self.idf = InputFormDescr(title = self.name)
            # append to idf here
            idf.append( {'name': 'template',
                         'widgetType': Tkinter.Button,
                         'wcfg': { 'text': 'template button label'},
                         'gridcfg': { 'sticky' : 'we'}})
            # only return idf for template
            return idf


    def guiCallback(self):
        """
        """
        idf_dict = self.showForm('template')
    
        # get the kw key:value pairs from the gui
        apply(self.doitWrapper, (), idf_dict)


    def doit(self, **kw):
        """The GUI command calls the real command here
        """
        # process keyword args here
        self.vf.ADpilot_Cluster()

ADpilot_ClusterGUI = CommandGUI()
ADpilot_ClusterGUI.addMenuCommand('AutoToolsBar',
                                   menuText['AutoPilotMB'],
                                   menuText['ClusterMB'],
                                   cascadeName = menuText['DatabaseMB'] )


#
# Template command and GUICommand
#
class ADpilot_Template(MVCommand):
    """A template command"""
    #
    # the signiture for __call__ must be compatible with that of doit!!!
    #
    def __call__(self, **kw):
        """This method is invoked by saying self.vf.ADpilot_Template
        in the Python Shell.
        """
        apply(self.doitWrapper, (), kw)


    def onAddCmdToViewer(self):
        """Initialization.

        This method is called by vf.addCommand (below)
        """
        pass



    def doit(self):
        """The real work gets done here
        """
        print 'in doit'



class ADpilot_TemplateGUICommand(MVCommand):
    """A template GUI command"""

    #
    # signiture for __call__ must be compatible with that of doit!!!
    #
    def __call__(self, **kw):
        """This method is invoked by saying self.vf.ADpilot_TemplateGUICommand
        in the Python Shell.
        """
        apply(self.doitWrapper, (), kw)


    def onAddCmdToViewer(self):
        """Initialization.

        This method is called by vf.addCommand (below)
        """
        pass


    def buildFormDescr(self, formName):
        if formName == 'template':
            idf = self.idf = InputFormDescr(title = self.name)
            # append to idf here
            idf.append( {'name': 'template',
                         'widgetType': Tkinter.Button,
                         'wcfg': { 'text': 'template button label'},
                         'gridcfg': { 'sticky' : 'we'}})
            # only return idf for template
            return idf


    def guiCallback(self):
        """
        """
        idf_dict = self.showForm('template')
    
        # get the kw key:value pairs from the gui
        apply(self.doitWrapper, (), idf_dict)


    def doit(self, **kw):
        """The GUI command calls the real command here
        """
        # process keyword args here
        self.vf.ADpilot_Template()

ADpilot_TemplateGUI = CommandGUI()
ADpilot_TemplateGUI.addMenuCommand('AutoToolsBar',
                                   menuText['AutoPilotMB'],
                                   menuText['TemplateMB'])


# A convenient list of dictionaries with arguments for vf.addCommand
commandList = [
    # Cluster Command
    {'name': 'ADpilot_Cluster',
     'cmd': ADpilot_Cluster(),
     'gui': None},
    {'name': 'ADpilot_ClusterGC',
     'cmd': ADpilot_ClusterGUICommand(),
     'gui': ADpilot_ClusterGUI},

    # Template Command
    {'name': 'ADpilot_Template',
     'cmd': ADpilot_Template(),
     'gui': None},
    {'name': 'ADpilot_TemplateGC',
     'cmd': ADpilot_TemplateGUICommand(),
     'gui': ADpilot_TemplateGUI},
    ]


def initModule(vf):
    """Add each command in the modules's commandList into ViewerFramework
    """
    for dict in commandList:
        vf.addCommand(dict['cmd'], dict['name'], dict['gui'])

# To load this module, type into the adt python interpreter:
# self.loadModule('autopilotCommands', 'AutoDockTools', log = 0)




hostMacros = {
    'localhost': { 'host' : 'localhost',
                   'autogrid' : 'autogrid4',
                   'autodock' : 'autodock4',
                   'vina' : 'vina',
                   'queuetype' : 'int',
                   'userSpecific' : 0 },

    }




#!/usr/bin/env python

import os
from string import find

from MolKit import Read
from MolKit.pdbWriter import PdbWriter




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: pdbqt_to_pdb.py -s filename"
        print
        print "    Description of command..."
        print "        [-f]    pdbqt_filename"
        print "    Optional parameters:"
        print "        [-o]    alternative pdb_filename"
        print "        [-v]    verbose output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'f:o:v')

    except getopt.GetoptError, msg:
        print 'pdbqt_to_pdb.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-s: pdbqt_filename_stem
    pdbqt_filename =  None

    # optional parameters
    verbose = None
    pdb_filename =  None

    #'f:o:v'
    for o, a in opt_list:
        if o in ('-f', '--f'):
            pdbqt_filename = a
            stem = pdbqt_filename.split('.')[0]
            pdb_filename = stem + ".pdb"
            if verbose: print 'set pdbqt_filename to ', pdbqt_filename
        if o in ('-o', '--o'):
            pdb_filename = a 
            if verbose: 
                print 'set output pdb_filename to ', a
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-h', '--'):
            usage()
            sys.exit()


    if not pdbqt_filename:
        print 'pdbqt_to_pdb: pdbqt_filename must be specified.'
        usage()
        sys.exit()

    mols = Read(pdbqt_filename)
    if verbose: print 'read ', pdbqt_filename
    mol = mols[0]
    mol.buildBondsByDistance()
    #fix number for problem files with alternative positions
    mol.allAtoms.number = range(1, len(mol.allAtoms)+1)

    #pdb_filename = mol.name + '.pdb'
    writer = PdbWriter()
    writer.write(pdb_filename, mol.allAtoms, records=['ATOM', 'HETATM'])

    if verbose:
        print "wrote ", ctr, " atoms to", pdb_filename
    

# To execute this command type:
# pdbqt_to_pdb.py -f pdbqt_filename_stem [-o outputfilename] -v







#############################################################################
#
# Author: Ruth HUEY, Stefano FORLI
#
# Copyright: A. Olson TSRI 2010
#
#############################################################################


# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VSResultFilters.py,v 1.17 2010/10/05 22:48:37 rhuey Exp $
#
# $Id: VSResultFilters.py,v 1.17 2010/10/05 22:48:37 rhuey Exp $
#
#
#
#
#
#
#

"""
Assorted classes of filters for use in selecting subgroups of AutoDock VSResult files...

filter_instance.filter(VSResult.pdbqt) returns True/False 

10/2010: 
Added a few assorted filters to use in selecting subgroups of AutoDock Vina VSResult files...
"""


class Filter:
    """
        Base class for object to screen AutoDock4 VSResult.pdbqt files

        input for filter: a VSResult.pdbqt instance created by  AutoDockTools/Utilities24/process_VSResults.py 
        output: whether the VSResult passes the criteria
    """
    def __init__(self, criteria='base_class'): 
        self.criteria = criteria
        self.keyline = "BASECLASS"

    
    def get_lines(self, VSResult):
        fptr = open(VSResult)
        lines = fptr.readlines()
        fptr.close()
        #verify that it is a VSResult
        assert lines[0].find('VirtualScreeningResult')>-1
        for i in range(len(lines)):
            if lines[i].find(self.keyline)>-1:
                break
        return lines[i:]


    def filter(self, VSResult):
        return True



class EnergyFilter(Filter):
    """
        object to evaluate an AutoDock4 VSResult  results based on lowest energy of the docked result

        input: an AutoDockTools 'VSResult.pdbqt' 
        output: whether the best energy of VSResult  is smaller than energy 
        ....
        if LE==LC:
        USER  AD> rmsd, LE, clu_size, clu_e_range, dlgfilename, run#, b_curCRDs, b_LE, b_LC
        USER  AD> 0.000,-8.300,92,0.30,faah8930_ZINC00898689_xJ1_xtal_03.dlg,10,1,1,1
        ....

        LE!=LC:
        USER  AD> rmsd, LE, clu_size, clu_e_range, dlgfilename, run#, b_curCRDs, b_LE, b_LC
        USER  AD> 0.000,-5.800,3,1.36,faah8621_ZINC02025973_xJ1_xtal_00.dlg,9,1,1,0
        ....

        if LC:
        USER  AD> rmsd, LE_LC, clu_size, clu_e_range, dlgfilename, run#, b_curCRDs, b_LE, b_LC
        USER  AD> 0.000,-5.800,3,1.36,faah8621_ZINC02025973_xJ1_xtal_00.dlg,9,0,1,0
        USER  AD> 22.435,-5.690,1,0.00,faah8621_ZINC02025973_xJ1_xtal_01.dlg,21,0,0,0
        USER  AD> 15.463,-5.680,2,0.19,faah8621_ZINC02025973_xJ1_xtal_02.dlg,21,0,0,0
        USER  AD> 21.252,-5.590,6,0.69,faah8621_ZINC02025973_xJ1_xtal_00.dlg,14,0,0,0
        USER  AD> 20.951,-5.570,8,0.39,faah8621_ZINC02025973_xJ1_xtal_02.dlg,46,0,0,0
        USER  AD> 21.455,-5.540,2,0.45,faah8621_ZINC02025973_xJ1_xtal_00.dlg,16,0,0,0
        USER  AD> 12.891,-5.480,2,0.42,faah8621_ZINC02025973_xJ1_xtal_01.dlg,14,0,0,0
        USER  AD> 21.837,-5.450,2,0.64,faah8621_ZINC02025973_xJ1_xtal_02.dlg,22,0,0,0
        USER  AD> 5.672,-5.370,2,0.91,faah8621_ZINC02025973_xJ1_xtal_01.dlg,2,0,0,0
        USER  AD> 15.087,-5.340,3,0.93,faah8621_ZINC02025973_xJ1_xtal_02.dlg,1,0,0,0
        USER  AD> 11.694,-5.320,2,0.10,faah8621_ZINC02025973_xJ1_xtal_02.dlg,10,0,0,0
        USER  AD> 5.014,-5.31,9,0.70,faah8621_ZINC02025973_xJ1_xtal_01.dlg,47,1,0,1
        ....


    """
    
    def __init__(self, energy=0):
        self.criteria = "BE"  
        Filter.__init__(self, self.criteria)
        self.keyline = "USER  AD> rmsd,"
        self.energy = energy
        #print "self.energy=", self.energy

        
    def filter(self, VSResult ):
        lines = self.get_lines(VSResult)
        found = 0
        for nl in lines:
            #find current
            #USER  AD> 0.000,-7.470,39,0.60,faah8621_ZINC02026663_xJ1_xtal_00.dlg,30,1,1,1
            ll = nl.strip().split(',')
            #['USER  AD> 0.000', '-7.470', '39', '0.60', 'faah8621_ZINC02026663_xJ1_xtal_00.dlg', '30', '1', '1', '1\n']
            if len(ll)<3:
                break
            if ll[-3]=='1':
                found = 1
                break
        if not found:
            msg =  "improperly formatted file "+ VSResult
            print msg
            return 0
            #raise RuntimeError(msg)
        this_energy = float(ll[1])
        return this_energy<self.energy



class EnergyRangeFilter(Filter):
    """
        object to evaluate an AutoDock4 VSResult  results based on an energy range of best docked result

        input: an AutoDockTools 'VSResult.pdbqt' 
        output: whether the best energy of VSResult is within the specified
        range
        options: inclusive  
            by default inclusive is False so strict comparisons are used. 
            This means that a result passes ONLY if its best_energy is greater than 
            the specified min_energy AND less than the max_energy.
            If inclusive is True, a result passes  if its best_energy is greater than 
                or equal to min_energy AND less than or equal to the specified max_energy
        self.keyline = "USER  AD> binding"
        ....

    """
    
    def __init__(self, min_energy=0, max_energy=0, inclusive=False):
        self.criteria = "BE"  
        Filter.__init__(self, self.criteria)
        #self.keyline = "USER  AD> binding"
        self.keyline = "USER  AD> rmsd,"
        self.min_energy = min_energy
        self.max_energy = max_energy
        self.inclusive = inclusive
        if min_energy>max_energy:
            msg = "minimum energy %f greater than maximum energy %f"%(min_energy, max_energy)
            print msg
            return 0
            #raise RuntimeError(msg)

        
    def filter(self, VSResult):
        found = 0
        lines = self.get_lines(VSResult)
        for nl in lines:
            ll = nl.strip().split(',')
            if len(ll)<3:
                break
            if ll[-3]=='1':
                found = 1
                break
        if not found:
            msg =  "improperly formatted file "+ VSResult
            print msg
            return 0
            #raise RuntimeError(msg)
        best_energy = float(ll[1])
        result = self.min_energy<best_energy<self.max_energy
        if self.inclusive:
            result = self.min_energy<=best_energy<=self.max_energy
        return result




class ClusterSizeFilter(Filter):
    """
        object to evaluate an AutoDock4 VSResult pdbqt file based on size of the cluster  

        input: an AutoDockTools.Docking 'VSResult ' 
        output: whether the largest cluster in the VSResult  is at least as large as specified cluster_size
    """
    
    def __init__(self, cluster_size=0, inclusive=True): 
        self.criteria = "CLsize"
        Filter.__init__(self, self.criteria)
        self.keyline = "USER  AD> rmsd"
        self.cluster_size = cluster_size
        self.inclusive=inclusive

    def filter(self, VSResult ):
        lines = self.get_lines(VSResult)
        found = 0
        for line in lines:
            ll = line.strip().split(',')
            if len(ll)<3:
                break
            if ll[-3]=='1':
                #print "line=", line
                found = 1
                break
        if not found:
            msg =  "improperly formatted file "+ VSResult
            print msg
            return 0
            #raise RuntimeError(msg)
        clu_size = ll[2]
        result = int(clu_size) > self.cluster_size
        if self.inclusive: 
            result = int(clu_size) >= self.cluster_size
        return result



class ClusterPercentageFilter(Filter):
    """
        object to evaluate an AutoDock4 VSResult based on percentage of VSResult  in the largest cluster  

        input: an AutoDockTools.Docking 'VSResult ' 
        output: whether the largest cluster in the VSResult contains 
                at least the specified percentage of runs (docked results)
    """
    
    def __init__(self, percentage=0): 
        self.criteria = "CLpercentage"
        Filter.__init__(self, self.criteria)
        self.keyline = "USER  AD> binding"
        self.cluster_percentage = percentage
        self.verbose = False



    def filter(self, VSResult):
        lines = self.get_lines(VSResult)
        ll = lines[0].split()
        #   0   1      2    3    4   5    6    7
        #USER  AD> binding 2.00 129 runs  31 clusters
        #                        -4   -3  -2   -1
        nruns = int(ll[4])
        found = 0
        for line in lines[2:]:
            #USER  5.014  -5.310    **  9 0.70 *
            ll = line.strip().split(',')
            if len(ll)<3:
                break
            if ll[-3]=='1':
                found = 1
                break
        if not found:
            msg =  "improperly formatted file "+ VSResult
            print msg
            return 0
            #raise RuntimeError(msg)
        this_cl_nruns = int(ll[2])
        if self.verbose: print "this_cl_nruns = ", this_cl_nruns
        percent = 100.*(float(this_cl_nruns)/float(nruns))
        if self.verbose: 
            print "percent =", percent, " self.cluster_percentage=", self.cluster_percentage
        result =  percent >= self.cluster_percentage
        return result


        
class EnergyClusterSizeFilter(Filter):
    """
        object to evaluate an AutoDock4 VSResult results based on an energy and a size for the largest cluster
        
        input: an AutoDockTools.Docking 'VSResult' 
        output: whether the lowest energy is at least as small as specified value 
                AND 
                whether largest cluster in the VSResult is at least as large as specified cluster_size
    """

    def __init__(self, energy=0, cluster_size=0):
        self.criteria = "Energy_ClusterSize"  
        Filter.__init__(self, self.criteria)
        self.energyF = EnergyFilter(energy=energy)
        self.cluster_sizeF = ClusterSizeFilter(cluster_size=cluster_size)
        self.cluster_size = cluster_size


    def filter(self, VSResult):
        if not self.energyF.filter(VSResult):
            return False
        # so it passed the energy
        if not self.cluster_sizeF.filter(VSResult):
            return False
        # so it passed both the energy and cluster_size
        return True



class BestEnergyInLargestCluster(Filter):
    """
        object to screen an AutoDock4 VSResult based on whether the best energy conformation is in the largest cluster 

        input: an AutoDock VSResult 
        output: whether the VSResult passes these criteria
    """

    def __init__(self):
        self.criteria = "BE_LC"  
        Filter.__init__(self, self.criteria)
        self.keyline = "USER  AD> rmsd"

        
    def filter(self, VSResult ):
        lines = self.get_lines(VSResult)
        if lines[0].find("TORSDOF")>-1:
            return False
        lowestenergy_line = lines[1].strip()
        be_is_lc = 0
        if len(lowestenergy_line)>5:
            be_is_lc = lowestenergy_line.find("1,1,1")== len(lowestenergy_line) - 5 
        #be_is_lc = lowestenergy_line.find("1,1,1")!=-1 
        return be_is_lc



class EnergyInLargestCluster(Filter):
    """
        object to screen AutoDock4 VSResult based on the magnitude of best energy in the largest cluster 
        input: an AutoDock VSResult 
        output: whether the VSResult passes these criteria
    """

    def __init__(self, energy=0):
        self.criteria = "Energy_LC"  
        Filter.__init__(self, self.criteria)
        self.energy_criterion = energy
        self.keyline = "USER  AD> rmsd"


    def filter(self, VSResult):
        #check energy first
        lines = self.get_lines(VSResult)
        found = 0
        for line in lines:
            cline = line.strip()
            if cline=='ROOT':
                break
            #if cline.find("1,0,1")>-1 or cline.find("1,1,1")>-1: #??? is there a better way
            #find "USER  AD> 5.014,-5.31,9,0.70,faah8621_ZINC02025973_xJ1_xtal_01.dlg,47,1,0,1"
            #find "USER  AD> 0.000,-7.470,39,0.60,faah8621_ZINC02026663_xJ1_xtal_00.dlg,30,1,1,1"
            #but not "USER  AD> 0.000,-5.930,1,0.00,faah8621_ZINC02058450_xJ1_xtal_00.dlg,1,0,1,0"
            #and not "USER  AD> 0.000,-8.440,10,0.01,faah8621_ZINC02026051_xJ1_xtal_00.dlg,1,1,1,0"
            if cline.find("1,0,1")==len(cline)-5 or cline.find("1,1,1")==len(cline)-5: #??? is there a better way
                found = 1
                break
        if not found:
            #msg =  "improperly formatted file "+ VSResult
            #print msg
            return 0
            #raise RuntimeError(msg)
        #USER  AD> 5.014,-5.31,9,0.70,faah8621_ZINC02025973_xJ1_xtal_01.dlg,47,1,0,1
        ll_list = cline.split(',')
        be_lc = float(ll_list[1])
        #return whether best energy in largest cluster passes...
        return  be_lc<=self.energy_criterion




class EnergyPlusBestEnergyInLargestCluster(Filter):
    """
        object to screen AutoDock4 VSResult based on the magnitude of best energy AND 
                                              whether that conf is in the largest cluster 
        input: an AutoDock VSResult 
        output: whether the VSResult passes these criteria
    """

    def __init__(self, energy=0):
        self.criteria = "BE_LC"  
        Filter.__init__(self, self.criteria)
        self.energyF = EnergyFilter(energy=energy)
        self.be_lcF = BestEnergyInLargestCluster()
        self.keyline = "USER  AD> rmsd"


    def filter(self, VSResult):
        #check energy first
        if not self.energyF.filter(VSResult):
            return False
        #now check whether best energy is in largest cluster
        if not self.be_lcF.filter(VSResult):
            return False
        return  True



class LigandEfficiencyFilter(Filter):
    """
        object to screen AutoDock4 VSResult based on the 'ligand efficiency' measure which is the 
                            best energy divided by the number of heavy atoms in the ligand

        input: an AutoDock VSResult 
        output: whether the VSResult passes the criteria
    """

    def __init__(self, ligand_efficiency=0, verbose=False):
        self.criteria = "Ligand_efficiency"  
        Filter.__init__(self, self.criteria)
        self.ligand_efficiency = ligand_efficiency
        self.keyline = "USER  AD> ligand efficiency"
        self.verbose = verbose


    def filter(self, VSResult):
        lines = self.get_lines(VSResult)
        result = 0
        if lines[0].find('efficiency')>-1:
            ll = lines[0].strip().split()
            lig_eff = float(ll[-1])
            result = lig_eff<=self.ligand_efficiency
        else:
            #@@make this safer
            print VSResult, " missing expected line: 'USER  AD> ligand efficiency float'"
            msg =  "improperly formatted file "+ VSResult
            print msg + ": missing expected line: 'USER  AD> ligand efficiency float'"
            return 0
            #raise RuntimeError(msg)
        return result



class HydrogenBondInteractionFilter(Filter):       
    """
        object to screen AutoDock4 VSResults based on presence of a specific ligand-receptor hydrogen
            bond interaction, initialized with a file containing the residue(s) of interest in the receptor

        input: an AutoDock VSResult 
        output: whether there are any contacts between a docked pose in the  VSResult and the atoms in the 'receptor_file'
    """

    def __init__(self, receptor_str, find_all=False, verbose=False):
        self.criteria = "Interactions"  
        Filter.__init__(self, self.criteria)
        self.keyline = "USER  AD> lig_hb_atoms"
        self.receptor_str = receptor_str
        self.verbose = verbose
        

    def filter(self, VSResult):
        lines = self.get_lines(VSResult)
        #USER lig_hb_atoms : 4
        #USER xJ1_xtal:B:LYS45:NZ,HZ3~ZINC02028532_vs:d:<0>:O2
        #USER xJ1_xtal:B:LYS55:NZ,HZ3~ZINC02028532_vs:d:<0>:O6
        #USER xJ1_xtal:B:MET46:N,HN~ZINC02028532_vs:d:<0>:O4
        #USER xJ1_xtal:B:LYS55:NZ,HZ3~ZINC02028532_vs:d:<0>:O7
        num_hb_atoms = int(lines[0].split()[-1])
        found_interaction = False
        for i in range(num_hb_atoms):
            if lines[i+1].find(self.receptor_str)>-1:
                found_interaction = True
                break  #
        return found_interaction



class CloseContactInteractionFilter(Filter):       
    """
        object to screen AutoDock4 VSResult based on presence of specific ligand-receptor interactions
            initialized with a file containing the residue(s) of interest in the receptor

        input: an AutoDock VSResult 
        output: whether there are any contacts between a docked pose in the  VSResult and the atoms in the 'receptor_file'
    """

    def __init__(self, receptor_str, find_all=False, verbose=False):
        self.criteria = "Interactions"  
        Filter.__init__(self, self.criteria)
        self.keyline = "USER  AD> macro_close_ats:"
        self.receptor_str = receptor_str
        self.verbose = verbose
        

    def filter(self, VSResult):
        lines = self.get_lines(VSResult)
        #USER macro_close_ats: 19
        num_contacts = int(lines[0].split()[-1])
        found_interaction = False
        for i in range(num_contacts):
            if lines[i+1].find(self.receptor_str)>-1:
                found_interaction = True
                break  #
        return found_interaction



class VinaFilter:
    """
        Base class for object to screen VinaVSResult.pdbqt files
        input for filter: a VinaVSResult.pdbqt file created with AutoDockTools/Utilities24/process_VinaResult.py 
        output: whether the VinaVSResult passes the criteria
    """
    def __init__(self, criteria='base_class'): 
        self.criteria = criteria
        self.keyline = "BASECLASS"

    
    def get_lines(self, VSResult):
        fptr = open(VSResult)
        lines = fptr.readlines()
        fptr.close()
        #verify that it is a VSResult
        assert lines[0].find('AutoDockVina VirtualScreeningResult')>-1
        for i in range(len(lines)):
            if lines[i].find(self.keyline)>-1:
                break
        return lines[i:]


    def filter(self, VSResult):
        return True



class VinaEnergyFilter(VinaFilter):
    """
        object to evaluate a VinaVSResult  results based on energy 

        input: an AutoDockTools 'VinaVSResult.pdbqt' 
        output: whether the best energy of VinaVSResult  is smaller than energy 
        ....
        USER  AD>  2 of 9 MODELS
        USER  AD>  ligand efficiency  -0.2217
        USER  AD>  -5.10, 26.865, 27.587
        ....

    """
    
    def __init__(self, energy=0):
        self.criteria = "Energy"  
        VinaFilter.__init__(self, self.criteria)
        self.keyline = "USER  AD>  ligand efficiency"
        self.energy = energy

        
    def filter(self, VinaVSResult ):
        lines = self.get_lines(VinaVSResult)
        #lines[0]
        #USER  AD>  ligand efficiency  -0.2217
        #lines[1]
        #USER  AD>  -5.10, 26.865, 27.587
        info_line = lines[1] 
        ll = info_line.split()
        if len(ll)==5 and ll[3][-1]==',':
            found = 1
        else:
            msg =  "improperly formatted file "+ VSResult
            print msg
            return 0
            #raise RuntimeError(msg)
        this_energy = float(ll[2][:-1])
        #print " this_energy=", this_energy
        return this_energy<self.energy



class VinaEnergyRangeFilter(VinaFilter):
    """
        object to evaluate a VinaVSResult  results based on an energy range of best docked result
        input: an AutoDockTools 'VinaVSResult.pdbqt' 
        output: whether the energy of VinaVSResult is within the specified range
        options: inclusive  
            by default inclusive is False so strict comparisons are used. 
            This means that a result passes ONLY if its best_energy is greater than 
            the specified min_energy AND less than the max_energy.
            If inclusive is True, a result passes  if its best_energy is greater than 
                or equal to min_energy AND less than or equal to the specified max_energy
        self.keyline = "USER  AD>  ligand efficiency"
        ....

    """
    
    def __init__(self, min_energy=0, max_energy=0, inclusive=False):
        if min_energy>max_energy:
            msg = "minimum energy %f greater than maximum energy %f"%(min_energy, max_energy)
            print msg
            return 0
        self.criteria = "Energy"  
        VinaFilter.__init__(self, self.criteria)
        self.min_filter = VinaEnergyFilter(min_energy)
        self.max_filter = VinaEnergyFilter(max_energy)
        self.inclusive = inclusive


    def filter(self, VinaVSResult ):
        min_ok = self.min_filter.filter(VinaVSResult)
        max_ok = self.max_filter.filter(VinaVSResult)
        #print "returning ", max_ok and not min_ok
        return max_ok and not min_ok


class VinaLigandEfficiencyFilter(VinaFilter):
    """
       object to screen VinaVSResult results based on the 'ligand efficiency' measure which is the 
                           best energy divided by the number of heavy atoms in the ligand

       input: an AutoDock VinaVSResult.pdbqt 
       output: whether the VinaVSResult passes the criteria
    """
    def __init__(self, ligand_efficiency=0, verbose=False):
        self.criteria = "Ligand_efficiency"  
        VinaFilter.__init__(self, self.criteria)
        self.ligand_efficiency = ligand_efficiency
        self.keyline = "USER  AD>  ligand efficiency"
        self.verbose = verbose


    def filter(self, VinaVSResult ):
        lines = self.get_lines(VinaVSResult)
        #lines[0]
        #USER  AD>  ligand efficiency  -0.2217
        #lines[1]
        #USER  AD>  -5.10, 26.865, 27.587
        info_line = lines[0] 
        ll = info_line.split()
        if len(ll)==5:
            found = 1
        else:
            msg =  "improperly formatted file "+ VinaVSResult
            print msg
            return 0
            #raise RuntimeError(msg)
        this_efficiency = float(ll[4].strip())
        #print " this_efficiency =", this_efficiency
        return this_efficiency<self.ligand_efficiency


###NO VinaHydrogenBondInteractionFilter because spherical model used for hydrogen positions
###class HydrogenBondInteractionFilter(Filter):       
###    """
###        class for object to screen VSResult results based on presence of a specific ligand-receptor hydrogen
###            bond interaction, initialized with a file containing the residue(s) of interest in the receptor

###        input: an AutoDock VSResult 
###        output: whether there are any contacts between a docked pose in the  VSResult and the atoms in the 'receptor_file'
###    """


class VinaCloseContactInteractionFilter(VinaFilter):       
    """
        class for object to screen VinaVSResult results based on presence of specific ligand-receptor interactions
            initialized with a file containing the residue(s) of interest in the receptor

        input: an AutoDock VinaVSResult 
        output: whether there are any contacts between a docked pose in the  VSResult and the atoms in the 'receptor_file'
    """

    def __init__(self, receptor_str, find_all=False, verbose=False):
        self.criteria = "Interactions"  
        VinaFilter.__init__(self, self.criteria)
        self.keyline = "USER  AD> macro_close_ats:"
        self.receptor_str = receptor_str
        self.verbose = verbose
        

    def filter(self, VinaVSResult):
        lines = self.get_lines(VinaVSResult)
        #USER macro_close_ats: 12
        num_contacts = int(lines[0].split()[-1])
        found_interaction = False
        for i in range(num_contacts):
            if lines[i+1].find(self.receptor_str)>-1:
                found_interaction = True
                break  #only need to find first...
        return found_interaction


